# type: ignore[attr-defined]
"""Un paquete para trabajar facilmente con metadatos de paises en latinoamerica."""

try:
    from importlib.metadata import PackageNotFoundError, version
except ImportError:  # pragma: no cover
    from importlib_metadata import PackageNotFoundError, version


try:
    __version__ = version(__name__)
except PackageNotFoundError:  # pragma: no cover
    __version__ = "unknown"


from . import paises
